@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10369 2017-10-14 09:46:18Z David $
+# $Id: views.py 10402 2017-10-24 08:16:47Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,13 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-14 17:46:18 +0800 (Sat, 14 Oct 2017) $
-# $Revision: 10369 $
+# $Date: 2017-10-24 16:16:47 +0800 (Tue, 24 Oct 2017) $
+# $Revision: 10402 $
 
 from django.conf import settings
-from django.shortcuts import redirect
+from django.shortcuts import render_to_response, get_object_or_404
+from django.utils.translation import ugettext_lazy as _
+from django.template import RequestContext
 
 from Iuppiter.extension.views import jsonpCallback, view
 from Iuppiter.dispatch import ThreadPool
@@ -84,42 +86,3 @@ def getMailingListInfo(request):
         pass
     return {'error': str(e)}
 
-def resendErrorContact(requset, newsletterId):
-    """
-    Resend newsletter to the contacts which has error when
-    sending mail previously.
-
-    @param request Request instance.
-    """
-    SENDBOX_THREAD_POOL_COUNT = settings.SENDBOX_THREAD_POOL_COUNT
-    ENABLE_FAKE_MAIL = settings.ENABLE_FAKE_MAIL
-    ENABLE_FAKE_SMTP = settings.ENABLE_FAKE_SMTP
-    LOG_LEVEL = settings.LOG_LEVEL
-    MAILER_LOGFILE = settings.MAILER_LOGFILE
-
-    sendboxPool = ThreadPool(SENDBOX_THREAD_POOL_COUNT)
-
-    mailerLogger = createLogger(
-                'theophrastusMailer', MAILER_LOGFILE, loggingLevel=LOG_LEVEL)
-
-    newsletter = Newsletter.objects.filter(id=newsletterId)[0]
-
-    contactIdSet = set(
-        ContactMailingStatus.objects.filter(
-            newsletter_id=newsletter.id, status=1).values_list('contact_id'))
-    contactIdList = [ele[0] for ele in list(contactIdSet)]
-    contactList = Contact.objects.filter(id__in=contactIdList)
-
-    mailer = CloudMailer(newsletter, pool=sendboxPool,
-                                     fakeMail=ENABLE_FAKE_MAIL,
-                                     fakeSMTP=ENABLE_FAKE_SMTP,
-                                     logger=mailerLogger)
-
-    mailer.useCloud = True if newsletter.server.id == 1 else False
-    mailer.smtp_connect()
-    mailer.attachments = mailer.getAttachments()
-
-    for contact in contactList:
-        mailer.send(contact)
-        
-    return redirect(newsletter.get_historic_url())
\ No newline at end of file
